@@ -36,6 +36,8 @@ def _delvewheel_init_patch_{0}():
     import sys
     libs_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, {1!r}))
     if sys.version_info[:2] >= (3, 8):
+        if os.path.exists(os.path.join(sys.base_prefix, 'conda-meta')):
+            os.environ['CONDA_DLL_SEARCH_MODIFICATION_ENABLE']='1'
         os.add_dll_directory(libs_dir)
     else:
         from ctypes import WinDLL
